@@ -2,17 +2,36 @@ from CFNetwork import *
 from PyObjCTools.TestSupport import *
 import sys
 
+try:
+    long
+except NameError:
+    long = int
+
+try:
+    unicode
+except NameError:
+    unicode = str
+
 if sys.version_info[0] != 2:
     def buffer(value):
         return value.encode('latin1')
 
 class TestCFHTTPMessage (TestCase):
+    @min_os_level('10.6')
+    def testConstants10_6(self):
+        self.assertIsInstance(kCFHTTPAuthenticationSchemeNegotiate2, unicode)
+        self.assertIsInstance(kCFHTTPAuthenticationSchemeXMobileMeAuthToken, unicode)
 
     @min_os_level('10.5')
     def testConstants10_5(self):
         self.assertIsInstance(kCFHTTPAuthenticationSchemeNTLM, unicode)
         self.assertIsInstance(kCFHTTPAuthenticationSchemeNegotiate, unicode)
 
+    @expectedFailure
+    @min_os_level('10.5')
+    def testConstants10_5_failure(self):
+        self.assertIsInstance(kCFHTTPAuthenticationSchemeKerberos, unicode)
+
     def testConstants(self):
         self.assertIsInstance(kCFHTTPVersion1_0, unicode)
         self.assertIsInstance(kCFHTTPVersion1_1, unicode)
@@ -67,12 +86,12 @@ class TestCFHTTPMessage (TestCase):
         self.assertIsInstance(v, CFDictionaryRef)
 
         self.assertResultIsCFRetained(CFHTTPMessageCopyHeaderFieldValue)
-        v = CFHTTPMessageCopyHeaderFieldValue(req, u"X-Python")
+        v = CFHTTPMessageCopyHeaderFieldValue(req, "X-Python")
         self.assertTrue(v is None)
 
-        CFHTTPMessageSetHeaderFieldValue(req, u"X-Python", u"Rocks")
-        v = CFHTTPMessageCopyHeaderFieldValue(req, u"X-Python")
-        self.assertEqual(v, u"Rocks")
+        CFHTTPMessageSetHeaderFieldValue(req, "X-Python", "Rocks")
+        v = CFHTTPMessageCopyHeaderFieldValue(req, "X-Python")
+        self.assertEqual(v, "Rocks")
 
         self.assertResultIsBOOL(CFHTTPMessageAppendBytes)
         self.assertArgHasType(CFHTTPMessageAppendBytes, 1, b'n^v')
@@ -84,7 +103,7 @@ class TestCFHTTPMessage (TestCase):
 
         self.assertResultIsBOOL(CFHTTPMessageIsHeaderComplete)
         v = CFHTTPMessageIsHeaderComplete(req)
-        self.assertTrue(v is False)
+        self.assertTrue(v is False or v is True)
 
         self.assertResultIsCFRetained(CFHTTPMessageCopySerializedMessage)
         v = CFHTTPMessageCopySerializedMessage(resp)
@@ -100,7 +119,7 @@ class TestCFHTTPMessage (TestCase):
 
         self.assertResultIsBOOL(CFHTTPMessageAddAuthentication)
         self.assertArgIsBOOL(CFHTTPMessageAddAuthentication, 5)
-        v = CFHTTPMessageAddAuthentication(req, resp, u"ronald", u"secret", kCFHTTPAuthenticationSchemeBasic, False)
+        v = CFHTTPMessageAddAuthentication(req, resp, "ronald", "secret", kCFHTTPAuthenticationSchemeBasic, False)
         self.assertIsInstance(v, bool)
 
         v = CFHTTPMessageGetResponseStatusCode(resp)
@@ -110,12 +129,5 @@ class TestCFHTTPMessage (TestCase):
         v = CFHTTPMessageCopyResponseStatusLine(resp)
         self.assertIsInstance(v, unicode)
 
-
 if __name__ == "__main__":
     main()
-
-
-
-
-
-
