@@ -2,12 +2,24 @@ from CFNetwork import *
 from PyObjCTools.TestSupport import *
 import os
 
+try:
+    long
+except NameError:
+    long = int
+
+try:
+    unicode
+except NameError:
+    unicode = str
+
 class TestCFHTTPStream (TestCase):
     @min_os_level('10.5')
     def testConstants10_5(self):
         self.assertIsInstance(kCFStreamPropertyHTTPFinalRequest, unicode)
 
     def testConstants(self):
+        self.assertIsInstance(kCFStreamErrorDomainHTTP, (int, long))
+
         self.assertEqual(kCFStreamErrorHTTPParseFailure, -1)
         self.assertEqual(kCFStreamErrorHTTPRedirectionLoop, -2)
         self.assertEqual(kCFStreamErrorHTTPBadURL, -3)
@@ -34,9 +46,9 @@ class TestCFHTTPStream (TestCase):
        v = CFReadStreamCreateForHTTPRequest(None, req)
        self.assertIsInstance(v, CFReadStreamRef)
 
-       fp = open("/dev/null", "w")
-       fd_2 = os.dup(2)
-       os.dup2(fp.fileno(), 2)
+       with open("/dev/null", "w") as fp:
+           fd_2 = os.dup(2)
+           os.dup2(fp.fileno(), 2)
 
        try:
            # Avoid deprecation messages from CFNetwork
@@ -48,7 +60,7 @@ class TestCFHTTPStream (TestCase):
            self.assertArgIsBOOL(CFHTTPReadStreamSetRedirectsAutomatically, 1)
            CFHTTPReadStreamSetRedirectsAutomatically(v, True)
 
-           CFHTTPReadStreamSetProxy(v, u"localhost", 8080)
+           CFHTTPReadStreamSetProxy(v, "localhost", 8080)
 
        finally:
            os.dup2(fd_2, 2)
