@@ -1,8 +1,26 @@
 from PyObjCTools.TestSupport import *
 from CFNetwork import *
 
+try:
+    long
+except NameError:
+    long = int
+
+try:
+    unicode
+except NameError:
+    unicode = str
+
 
 class TestCFSocketStream (TestCase):
+    @min_os_level('10.7')
+    def testConstants10_7(self):
+        self.assertIsInstance(kCFStreamNetworkServiceType, unicode)
+        self.assertIsInstance(kCFStreamNetworkServiceTypeVoIP, unicode)
+        self.assertIsInstance(kCFStreamNetworkServiceTypeVideo, unicode)
+        self.assertIsInstance(kCFStreamNetworkServiceTypeBackground, unicode)
+        self.assertIsInstance(kCFStreamNetworkServiceTypeVoice, unicode)
+
     @min_os_level('10.5')
     def testConstants10_5(self):
         self.assertIsInstance(kCFStreamPropertySSLPeerTrust, unicode)
@@ -37,6 +55,7 @@ class TestCFSocketStream (TestCase):
         self.assertEqual(kCFStreamErrorSOCKS4IdConflict, 93)
         self.assertEqual(kSOCKS5NoAcceptableMethod, 0xFF)
 
+        self.assertIsInstance(kCFStreamPropertySOCKSProxy, unicode)
         self.assertIsInstance(kCFStreamPropertySOCKSProxyHost, unicode)
         self.assertIsInstance(kCFStreamPropertySOCKSProxyPort, unicode)
         self.assertIsInstance(kCFStreamPropertySOCKSVersion, unicode)
@@ -77,7 +96,7 @@ class TestCFSocketStream (TestCase):
         self.assertArgIsOut(CFStreamCreatePairWithSocketToCFHost, 3)
         self.assertArgIsOut(CFStreamCreatePairWithSocketToCFHost, 4)
 
-        host = CFHostCreateWithName(None, u"connect.apple.com")
+        host = CFHostCreateWithName(None, "connect.apple.com")
         rd, wr = CFStreamCreatePairWithSocketToCFHost(None, host, 443, None, None)
         self.assertIsInstance(rd, CFReadStreamRef)
         self.assertIsInstance(wr, CFWriteStreamRef)
@@ -90,13 +109,17 @@ class TestCFSocketStream (TestCase):
         self.assertArgIsCFRetained(CFStreamCreatePairWithSocketToNetService, 3)
         self.assertArgIsOut(CFStreamCreatePairWithSocketToNetService, 2)
         self.assertArgIsOut(CFStreamCreatePairWithSocketToNetService, 3)
-        service = CFNetServiceCreate(None, u"pyobjc.local", u"ssh", u"pyobjc.test.local", 9999)
+        service = CFNetServiceCreate(None, "pyobjc.local", "ssh", "pyobjc.test.local", 9999)
         rd, wr = CFStreamCreatePairWithSocketToNetService(None, service, None, None)
         self.assertIsInstance(rd, CFReadStreamRef)
         self.assertIsInstance(wr, CFWriteStreamRef)
 
-
-
+    @min_os_level('10.8')
+    def testConstants10_8(self):
+        # XXX: iOS only:
+        #self.assertIsInstance(kCFStreamPropertySSLContext, unicode)
+        self.assertIsInstance(kCFStreamPropertyNoCellular, unicode)
+        self.assertIsInstance(kCFStreamPropertyConnectionIsCellular, unicode)
 
 if __name__ == "__main__":
     main()
